clear
local path="C:\Users\a0910846\Dropbox\FivaNatvik2013_Replication"
cd `path'
cap mkdir "`path'\tables"

**********************************************************************************************
************************ DESCRIPTIVES - TABLE 1  *********************************************
**********************************************************************************************

use "`path'\FivaNatvik_Descriptives.dta"

sutex InvAggregate InvEduc InvElderly InvChild CurrAggregate CurrEduc CurrElderly CurrChild  , /// 
minmax title(Descriptive Statistics: Investment and Current Expenditures\label{DescrStatsLevel}) ///
file(tables/Table1.tex) replace

**********************************************************************************************
************************ DESCRIPTIVES - TABLE 3  *********************************************
**********************************************************************************************

keep if post_storting==1
sutex mayor_left mayor_right voteshare_left voteshare_right SupportLocalElection SupportNationalElection ree ch_support ch_support_county,   ///
minmax title(Descriptive Statistics: Political Variables. \label{DescrStatsPol2}) ///
file(tables\Table3.tex) replace


**********************************************************************************************
************************ MAIN ANALYSIS - DATA MANIPULAITON  **********************************
**********************************************************************************************
clear
use "`path'\FivaNatvik_Main.dta"
xtset knr electionperiod
local sectors ag ed el ch

drop if seatshare_other>0
drop if pop<1000

foreach sector of local sectors {
drop if ch_invest_`sector' ==.
drop if ch_currexp_`sector' ==.
} 

keep if sample==1

**********************************************************************************************
************************ DESCRIPTIVES - TABLE 2  *********************************************
**********************************************************************************************

sutex ch_invest_aggr ch_invest_ed ch_invest_el ch_invest_ch ch_currexp_aggr ch_currexp_ed ch_currexp_el ch_currexp_ch  , /// 
minmax title(Descriptive Statistics: First Differences in Investment and Current Expenditures\label{DescrStatsDiff}) ///
file(tables/Table2.tex) replace

**********************************************************************************************
****TABLE 4 - INFORMATION FROM PARLIAMENTARY ELECTION RIGHT BLOC MAYORS **********************
**********************************************************************************************

eststo clear
dprobit reelect SupportLocalElection  d_ele* if mayor_left==0, cluster(knr)
mat def A=e(dfdx)
eststo
estadd mat margeff=A
estadd local EstMethod "Probit"
estadd local Mayor "Right"
dprobit reelect SupportNationalElection  d_ele* if mayor_left==0, cluster(knr)
mat def A=e(dfdx)
eststo
estadd mat margeff=A
estadd local EstMethod "Probit"
estadd local Mayor "Right"
dprobit reelect SupportLocalElection SupportNationalElection  d_ele* if mayor_left==0, cluster(knr)
mat def A=e(dfdx)
eststo
estadd mat margeff=A
estadd local EstMethod "Probit"
estadd local Mayor "Right"
esttab using tables/Table4a.tex, replace aux(margeff) ///
width(\hsize) style(tex) ///
b(%9.2f)  ///
title(Information from Parliamentary Election \label{Probreelect}) ///
nonumbers mtitles("Right-wing" "Right-wing" "Right-wing") ///
scalars("EstMethod Estimation Method") ///
star(* 0.10 ** 0.05 *** 0.01) pr2 ///
drop(_cons d_ele* )

**********************************************************************************************
****TABLE 4 - INFORMATION FROM PARLIAMENTARY ELECTION LEFT BLOC MAYORS ***********************
**********************************************************************************************

eststo clear
dprobit reelect SupportLocalElection  d_ele* if mayor_left==1, cluster(knr)
mat def A=e(dfdx)
eststo
estadd mat margeff=A
estadd local EstMethod "Probit"
estadd local Mayor "Left"
dprobit reelect SupportNationalElection  d_ele* if mayor_left==1, cluster(knr)
mat def A=e(dfdx)
eststo
estadd mat margeff=A
estadd local EstMethod "Probit"
estadd local Mayor "Left"
dprobit reelect SupportLocalElection SupportNationalElection  d_ele* if mayor_left==1, cluster(knr)
mat def A=e(dfdx)
eststo
estadd mat margeff=A
estadd local EstMethod "Probit"
estadd local Mayor "Left"
esttab using tables/Table4b.tex, replace aux(margeff) ///
width(\hsize) style(tex) ///
b(%9.2f)  ///
title(Information from Parliamentary Election \label{Probreelect}) ///
nonumbers mtitles("Left-wing" "Left-wing" "Left-wing") ///
scalars("EstMethod Estimation Method") ///
star(* 0.10 ** 0.05 *** 0.01) pr2 ///
drop(_cons d_ele* )

**********************************************************************************************
*********************************TABLE 5 - FIRST STAGE ***************************************
**********************************************************************************************


eststo clear
reg ch_support ch_support_county d_ele* if mayor_left==0 , cluster(knr) 
eststo
estadd local Est "OLS"

reg ch_support ch_support_county d_ele* if mayor_left==1 , cluster(knr) 
eststo
estadd local Est "OLS"

esttab using tables/Table5.tex, replace style(tex) r2 star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Right-wing Mayors" "Left-wing Mayors") ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f) ///
scalars("Est Estimation Method") ///
coeflabels (ch_support_county "$\Delta Support^{County}$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}") nodep 


**********************************************************************************************
************************ IV REGRESSIONS - INVESTMENT TABLE 6 *********************************
**********************************************************************************************

/* IV - INVEST - Non-Socialist*/

eststo clear
foreach sector of local sectors{
replace dep= ch_invest_`sector' 
ivreg2 dep d_ele* (ch_support=ch_support_county)  if mayor_left==0, cluster(knr) ffirst 
estout
eststo 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table6a.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\newline" "\end{tabular}") nodep 

/* IV - INVEST - SOCIALIST */

eststo clear
foreach sector of local sectors{
replace dep= ch_invest_`sector' 
ivreg2 dep d_ele* (ch_support=ch_support_county)  if mayor_left==1, cluster(knr) ffirst 
eststo 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table6b.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}") nodep

**********************************************************************************************
************************ IV REGRESSIONS - CURR.EXP TABLE 7 ***********************************
**********************************************************************************************

/* IV - DRIFT - Non-Socialist*/

eststo clear
foreach sector of local sectors{
replace dep= ch_currexp_`sector' 
ivreg2 dep d_ele* (ch_support=ch_support_county)  if mayor_left==0, cluster(knr) ffirst
eststo 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table7a.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\newline" "\end{tabular}") nodep 

/* IV - DRIFT - SOCIALIST */

eststo clear
foreach sector of local sectors{
replace dep= ch_currexp_`sector' 
ivreg2 dep d_ele* (ch_support=ch_support_county)  if mayor_left==1, cluster(knr) ffirst
eststo 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table7b.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}") nodep



**********************************************************************************************
************************ OLS REGRESSIONS - INVEST TABLE 8 ************************************
**********************************************************************************************

sort knr electionperiod

preserve
drop if ch_support_county==.

/* OLS - INVEST - Non-Socialist */

eststo clear
foreach sector of local sectors{
replace dep=ch_invest_`sector' 
reg dep d_ele* ch_support if mayor_left==0, cluster(knr)
estout
eststo 
estadd local Est "OLS"
}
esttab using tables/Table8a.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mlabels("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)  ///
///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\newline" "\end{tabular}") nodep 

/* OLS - INVEST - SOCIALIST */

eststo clear
foreach sector of local sectors{
replace dep= ch_invest_`sector' 
reg dep d_ele* ch_support if mayor_left==1, cluster(knr)
estout
eststo 
estadd local Est "OLS"
}
esttab using tables/Table8b.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}") nodep


**********************************************************************************************
************************ OLS REGRESSIONS - CURREXP TABLE 9 ***********************************
**********************************************************************************************

/* OLS - DRIFT - Non-Socialist*/

eststo clear
foreach sector of local sectors{
replace dep= ch_currexp_`sector' 
reg dep d_ele* ch_support if mayor_left==0, cluster(knr)
estout
eststo 
estadd local Est "OLS"
}
esttab using tables/Table9a.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\newline" "\end{tabular}") nodep 

/* OLS - DRIFT - SOCIALIST */

eststo clear
foreach sector of local sectors{
replace dep= ch_currexp_`sector' 
reg dep d_ele* ch_support if mayor_left==1, cluster(knr)
estout
eststo 
estadd local Est "OLS"
}
esttab using tables/Table9b.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}") nodep

restore


**********************************************************************************************
*********************** IV REGRESSIONS - INVESTMENT CONTROLS TABLE 10 ************************
**********************************************************************************************

/* IV - INVEST - Non-Socialist*/

eststo clear
foreach sector of local sectors{
replace dep= ch_invest_`sector' 
ivreg2 dep ch_pop ch_chi ch_you ch_eld ch_women ch_marriedwomen ch_unemp  d_ele* (ch_support=ch_support_county)  if mayor_left==0, cluster(knr) ffirst 
estout
eststo 
 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table10a.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\newline" "\end{tabular}") nodep 

/* IV - INVEST - SOCIALIST */

eststo clear
foreach sector of local sectors{
replace dep= ch_invest_`sector' 
ivreg2 dep  ch_pop ch_chi ch_you ch_eld ch_women ch_marriedwomen ch_unemp  d_ele* (ch_support=ch_support_county)  if mayor_left==1, cluster(knr) ffirst 
eststo 
 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table10b.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}") nodep


**********************************************************************************************
************************ IV REGRESSIONS - CURR.EXP. CONTROLS TABLE 11 ************************
**********************************************************************************************

/* IV - DRIFT - Non-Socialist*/
eststo clear
foreach sector of local sectors{
replace dep= ch_currexp_`sector' 
ivreg2 dep ch_pop ch_chi ch_you ch_eld ch_women ch_marriedwomen ch_unemp  d_ele* (ch_support=ch_support_county)  if mayor_left==0, cluster(knr) ffirst
eststo 
 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table11a.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\newline" "\end{tabular}") nodep 

/* IV - DRIFT - SOCIALIST */
eststo clear
foreach sector of local sectors{
replace dep= ch_currexp_`sector' 
ivreg2 dep ch_pop ch_chi ch_you ch_eld ch_women ch_marriedwomen ch_unemp  d_ele* (ch_support=ch_support_county)  if mayor_left==1, cluster(knr) ffirst
eststo 
 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table11b.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}") nodep


**********************************************************************************************
************************ IV REGRESSIONS - COUNTY ADM EXCLUDED TABLE 12 ***********************
**********************************************************************************************
preserve
drop if countyadm==1

/* IV - INVEST - Non-Socialist*/

eststo clear
foreach sector of local sectors{
replace dep= ch_invest_`sector' 
ivreg2 dep d_ele* (ch_support=ch_support_county_nocountyadm)  if mayor_left==0, cluster(knr) ffirst 
estout
eststo 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table12a.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\newline" "\end{tabular}") nodep 

/* IV - INVEST - SOCIALIST */

eststo clear
foreach sector of local sectors{
replace dep= ch_invest_`sector' 
ivreg2 dep d_ele* (ch_support=ch_support_county_nocountyadm)  if mayor_left==1, cluster(knr) ffirst 
eststo 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table12b.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}") nodep


**********************************************************************************************
************************ IV REGRESSIONS - COUNTY ADM EXCLUDED TABLE 13 ***********************
**********************************************************************************************

/* IV - DRIFT - Non-Socialist*/

eststo clear
foreach sector of local sectors{
replace dep= ch_currexp_`sector' 
ivreg2 dep d_ele* (ch_support=ch_support_county_nocountyadm)  if mayor_left==0, cluster(knr) ffirst
eststo 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table13a.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\newline" "\end{tabular}") nodep 

/* IV - DRIFT - SOCIALIST */

eststo clear
foreach sector of local sectors{
replace dep= ch_currexp_`sector' 
ivreg2 dep d_ele* (ch_support=ch_support_county_nocountyadm)  if mayor_left==1, cluster(knr) ffirst
eststo 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table13b.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}") nodep


**********************************************************************************************
************************ IV REGRESSIONS - EXCLUDING REGION IN INSTRUMENT TABLE 14 ************
**********************************************************************************************

restore
preserve

/* IV - INVEST - Non-Socialist*/

eststo clear
foreach sector of local sectors{
replace dep= ch_invest_`sector' 
ivreg2 dep d_ele* (ch_support=ch_support_county_noregion)  if mayor_left==0, cluster(knr) ffirst 
estout
eststo 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table14a.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\newline" "\end{tabular}") nodep 

/* IV - INVEST - SOCIALIST */

eststo clear
foreach sector of local sectors{
replace dep= ch_invest_`sector' 
ivreg2 dep d_ele* (ch_support=ch_support_county_noregion)  if mayor_left==1, cluster(knr) ffirst 
eststo 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table14b.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}") nodep


**********************************************************************************************
************************ IV REGRESSIONS - EXCLUDING REGION IN INSTRUMENT TABLE 15 ************
**********************************************************************************************

/* IV - DRIFT - Non-Socialist*/

eststo clear
foreach sector of local sectors{
replace dep= ch_currexp_`sector' 
ivreg2 dep d_ele* (ch_support=ch_support_county_noregion)  if mayor_left==0, cluster(knr) ffirst
eststo 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table15a.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\newline" "\end{tabular}") nodep 

/* IV - DRIFT - SOCIALIST */

eststo clear
foreach sector of local sectors{
replace dep= ch_currexp_`sector' 
ivreg2 dep d_ele* (ch_support=ch_support_county_noregion)  if mayor_left==1, cluster(knr) ffirst
eststo 
estadd local Est "IV"
estadd scalar Ftest=el(e(first),3,1)
}
esttab using tables/Table15b.tex, replace style(tex) star(* 0.10 ** 0.05 *** 0.01) ///
nonumbers mtitles("Aggregate" "Education" "Elderly Care" "Child Care")  ///
drop(*d_ele* _cons) se b(%9.2f) se(%9.2f)   ///
scalars("Ftest F-statistic from 1st.") ///
coeflabels (ch_unemp "$\Delta Unemp$" ch_support "$\Delta Support$" ch_pop "$\Delta Pop$" ch_children "$\Delta Children$" ch_young "$\Delta Young$" ch_elderly "$\Delta Elderly$" ch_women "$\Delta Women$" ch_marriedwomen "$\Delta MarriedWomen$") ///
prehead("\begin{tabular}{l*{@M}{rr}}" "\hline") posthead(\hline) postfoot("\hline" "\end{tabular}") nodep



